CacheEntry<K, V> class

Represents an entry in the cache with metadata for eviction algorithms.

Constructors

CacheEntry({required K key, required V value, int frequency = 1, DateTime? lastAccessed})

Properties

frequency ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key → K
final
lastAccessed ↔ DateTime
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → V
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
updateAccess() → void
Updates the access metadata for this entry.

Operators

operator ==(Object other) → bool
The equality operator.
inherited